aboutsummaryrefslogtreecommitdiff
path: root/include/sqfs/dir.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/sqfs/dir.h')
-rw-r--r--include/sqfs/dir.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/include/sqfs/dir.h b/include/sqfs/dir.h
index 8a76f3d..6f7dadf 100644
--- a/include/sqfs/dir.h
+++ b/include/sqfs/dir.h
@@ -41,7 +41,7 @@
*/
struct sqfs_dir_header_t {
/**
* @brief The number of @ref sqfs_dir_entry_t entries that are
* following.
*
* This value is stored off by one and the total count must not
@@ -63,7 +63,7 @@ struct sqfs_dir_header_t {
};
/**
- * @struct sqfs_dir_entry_t
+ * @struct sqfs_dir_node_t
*
* @brief On-disk data structure of a directory entry. Many of these
* follow a single @ref sqfs_dir_header_t.
@@ -71,7 +71,7 @@ struct sqfs_dir_header_t {
* See @ref sqfs_dir_writer_t for an overview on how SquashFS stores
* directories on disk.
*/
-struct sqfs_dir_entry_t {
+struct sqfs_dir_node_t {
/**
* @brief An offset into the uncompressed meta data block containing
* the coresponding inode.
@@ -41,7 +41,7 @@
struct sqfs_dir_header_t {
/**
- * @brief The number of @ref sqfs_dir_entry_t entries that are
+ * @brief The number of @ref sqfs_dir_node_t entries that are
* following.
*